@@ -91,8 +91,8 @@ class Logger:
 
     def __init__(self, name: str,
                  time_format: str = None,
-                 min_loglevel: LogLevel = LogLevel.INFO,
-                 max_loglevel: LogLevel = LogLevel.CRITICAL) -> None:
+                 min_loglevel: LogLevel = None,
+                 max_loglevel: LogLevel = None) -> None:
         """
         Initializes the Logger with the given name, time format, and log
         levels.
